-
connectTimeout
↔ Duration?
-
Timeout when opening a request.
getter/setter pairinherited
-
contentType
↔ String?
-
The request content-type.
getter/setter pairinherited
-
An extra map that you can retrieve in
Interceptor, Transformer
and Response.requestOptions.
getter/setter pairinherited
-
followRedirects
↔ bool?
-
See HttpClientRequest.followRedirects.
getter/setter pairinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
HTTP request headers.
getter/setter pairinherited
-
listFormat
↔ ListFormat?
-
Indicates the format of collection data in request query parameters and
x-www-url-encoded body data.
getter/setter pairinherited
-
maxRedirects
↔ int?
-
The maximum number of redirects when
followRedirects is true.
RedirectException will be thrown if redirects exceeded the limit.
getter/setter pairinherited
-
method
↔ String?
-
The HTTP request method.
getter/setter pairinherited
-
persistentConnection
↔ bool?
-
See HttpClientRequest.persistentConnection.
getter/setter pairinherited
-
Whether the case of header keys should be preserved.
getter/setter pairinherited
-
receiveDataWhenStatusError
↔ bool?
-
Whether to retrieve the data if status code indicates a failed request.
getter/setter pairinherited
-
receiveTimeout
↔ Duration?
-
Timeout when receiving data.
getter/setter pairinherited
-
requestEncoder
↔ RequestEncoder?
-
The type of a request encoding callback.
getter/setter pairinherited
-
responseDecoder
↔ ResponseDecoder?
-
The type of a response decoding callback.
getter/setter pairinherited
-
responseType
↔ ResponseType?
-
The type of data that
Dio handles with options.
getter/setter pairinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sendTimeout
↔ Duration?
-
Timeout when sending data.
getter/setter pairinherited
-
validateStatus
↔ ValidateStatus?
-
Defines whether the request is considered to be successful
with the given status code.
The request will be treated as succeed if the callback returns true.
getter/setter pairinherited